pub struct InitConfigArgs {
pub file: PathBuf,
pub new_mint: bool,
pub existing_mint: bool,
pub allow_new_bdk_wallet: bool,
}Expand description
Arguments for initializing database-backed configuration.
Fields
file: PathBufTOML document to import.
new_mint: boolInitialize a database that has never served a mint.
existing_mint: boolImport configuration into a database containing an existing mint.
allow_new_bdk_wallet: boolPermit an existing mint to create a BDK wallet when no wallet database exists.