pub struct MintManagementRpc {
pub enabled: bool,
pub address: Option<String>,
pub port: Option<u16>,
pub tls_dir: Option<PathBuf>,
pub allow_insecure: bool,
pub allow_mint_quote_payment_override: bool,
}Fields
enabled: boolWhen this is set to true the mint use the config file for the initial set up on first start.
Changes to the [mint_info] after this MUST be made via the RPC changes to the config file or env vars will be ignored.
address: Option<String>port: Option<u16>tls_dir: Option<PathBuf>allow_insecure: boolallow_mint_quote_payment_override: boolAllow management RPC callers to use mint quote state override endpoints.
This includes marking quotes paid without backend confirmation and is disabled by default.
Implementations